#
# spec file for package anki
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tests
Name:           anki
Version:        2.1.11
Release:        lp150.17.1
Summary:        Spaced-Repetition Memory Training Program
License:        AGPL-3.0-only
Group:          Productivity/Text/Utilities
URL:            https://apps.ankiweb.net/
Source0:        https://apps.ankiweb.net/downloads/current/%{name}-%{version}-source.tgz
Source1:        %{name}.appdata.xml
# PATCH-FIX-OPENSUSE - anki-aqt___init__.py.patch -- Load Qt4 translations from the right place
Patch1:         %{name}-aqt___init__.py.patch
# PATCH-FIX-OPENSUSE - anki-anki_lang.py.patch -- Load Anki translations from the right place
Patch2:         %{name}-anki_lang.py.patch
BuildRequires:  python3-Markdown
BuildRequires:  python3-PyAudio
BuildRequires:  python3-Send2Trash
BuildRequires:  python3-beautifulsoup4
BuildRequires:  python3-decorator
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-requests
Requires:       python3-Markdown
Requires:       python3-PyAudio
Requires:       python3-Send2Trash
Requires:       python3-beautifulsoup4
Requires:       python3-decorator
Requires:       python3-qt5
Requires:       python3-requests
Suggests:       lame
Suggests:       mpv
Suggests:       sox
BuildArch:      noarch
%if 0%{?suse_version} >= 1550
Requires:       python3-qtwebengine-qt5
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
%if %{with tests}
BuildRequires:  python3-nose
%endif

%description
Anki is a spaced repetition system (SRS). It helps the user remember things by
scheduling reviews, so that the user can learn a lot of information
with the minimum amount of effort.
Anki is content-agnostic and supports images, audio,
videos and scientific markup (via LaTeX).

Anki stores data in ~/.local/share/Anki2, or $XDG_DATA_HOME/Anki2
if the user has set a custom data path.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

# SED-FIX-OPENSUSE -- Don't check for new updates.
sed -i -e 's|updates=True|updates=False|;
           s|suppressUpdate=False|suppressUpdate=True|' aqt/profiles.py

# Use dependencies instead of bundled stuff
rm -rf thirdparty

# Remove not needed files
rm -f anki/anki

%build
./tools/build_ui.sh
python3 -m compileall .
python3 -O -m compileall .

%install
%make_install

# install appdata
mkdir -p %{buildroot}%{_datadir}/appdata
install -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/appdata

# install mime data
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -m 0644 %{name}.xml %{buildroot}%{_datadir}/mime/packages/

# Remove duplicate and unneeded doc files
rm %{buildroot}%{_datadir}/doc/anki/LICENSE
rm %{buildroot}%{_datadir}/doc/anki/LICENSE.logo
rm %{buildroot}%{_datadir}/doc/anki/README.contributing
rm %{buildroot}%{_datadir}/doc/anki/README.development
rm %{buildroot}%{_datadir}/doc/anki/README.md

%find_lang %{name} %{name}.lang

%if 0%{?suse_version}
    %suse_update_desktop_file -r %{name} Education Languages
    %fdupes -s %{buildroot}%{_prefix}
%endif

# Fix rpmlint issues
find %{buildroot}%{_datadir}/%{name}/web/ -name '*.js' -exec chmod a-x {} +
sed -i 's|/usr/bin/env python3|python3|' %{buildroot}%{_bindir}/%{name}

%check
%if %{with tests}
# to prevent Exception("Anki requires a UTF-8 locale.")
export LC_ALL=en_US.UTF-8
./tools/tests.sh
%endif

%post
update-mime-database %{_datadir}/mime

%postun
update-mime-database %{_datadir}/mime

%files -f %{name}.lang
%doc README.md
%license LICENSE LICENSE.logo
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/%{name}

%changelog
* Mon Mar 18 2019 Ismail Dönmez <idonmez@suse.com>
- For suse_version >= 1550 we have to depend on python3-qtwebengine-qt5
  as it's split as a package now.
* Sun Mar 17 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to 2.1.11:
  * Change Undo shortcut back to Ctrl+Alt+Z/Cmd+Opt+Z in Browse screen, to
    prevent accidentally undoing non-text changes when editing fields.
  * Revert a previous card template optimization that could cause an error.
  * Suppress a spurious error message that could occur when editing.
  2.1.10:
  * Add option to strip html in export.
  * Avoid nbsp for single spaces when pasting text.
  * Fix preview screen flashing when moving between cards.
  * Improvements to the add-ons screen (thanks to Glutanimate).
  * Support .ankiaddon bundles (thanks to Glutanimate).
  * Improve subpixel antialiasing on some machines (thanks to Glutanimate).
  * Improve Japanese interface font on Windows 10, and make it possible for
    translators to change the font for other languages that need it as well.
  * Fix inability to start if problem occurs on first run.
  * Allow decreasing daily limits in custom study.
  * Add a button to copy debug info to about screen (thanks to Glutanimate).
  * Fix problem running from source on Windows (thanks to dlon).
  * Allow add-ons to serve files from mediasrv (thanks to Glutanimate).
  * More user-friendly error messages for some network errors.
  2.1.9:
  * Update standard build to latest toolkit version.
  * Hardware acceleration defaults to off again on Windows/Linux, due to the
    issues it was causing some users. If you were not experiencing any
  issues, turning hardware acceleration back on in the preferences screen
  is recommended.
  * Various statistics fixes for the V2 scheduler, including an automatic
    remapping of button 2/3 in the review history when moving back and forth
  between scheduler versions so the "answer buttons" graph displays
  correctly.
  * Fix BR tags being included in empty fields (thanks to David and zjosua)
  * Optimize card template repositioning (thanks to Arthur)
  * Fix a crash when copying/cutting with an empty selection (thanks to David)
  * Avoid screen flash when undoing reviews.
  * Make sure info/warning dialogs appear on top.
  * Fixed an issue with just-typed text not being saved when using the mouse
    to save/add a card.
  * Added support for {{CardFlag}}, which is either empty, or in the format
    "flagN" where N is 1-4.
  * Fix bulk flag changes in Browse screen not syncing.
  * Fix advanced menu in editor not showing shortcut keys.
  * When UI fails to load after resuming computer from sync, show a tooltip
    and automatically refresh.
  * Clean up old mplayer instances after a crash so that profile renaming
    works.
  * Fix add-on list not refreshing when toggling enabled in latest toolkit.
  * Fix cursor jumping on first click in "Edit Current" area on Windows.
  * Preserve whitespace when pasting plain text.
  * Prevent errors caused by a timer firing after collection is unloaded.
  * Ensure a full sync is forced when restoring from a backup.
  * Ensure full window is on screen when displaying windows on a changed
    screen layout.
  * Improvements to the add-ons, debug console, and error screens
    (thanks to Glutanimate)
  * Ensure {{Deck}} shows the correct deck when adding (thanks to Arthur)
  * Ensure windows don’t get shown off-screen.
  * Remember add-on window size and position.
  2.1.8:
  * Fix startup on Windows 8.
  * Fix field content appearing under editor buttons.
  * Better handle an error when recording.
  * Fix improper handling of collections with deck errors.
  * Fix duplicate deck names being created due to text encoding.
  * Fix gtk2 theme and fcitx module not being included.
  * Detect nouveau graphics drivers and automatically switch to software
    rendering.
- run spec-cleaner
* Thu Jan 24 2019 l.lunak@centrum.cz
- anki-anki_lang.py.patch: Also install .mo files in the proper
  location.
* Fri Dec 28 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and generalize description.
* Thu Dec 20 2018 Martin Herkt <9+suse@cirno.systems>
- Update to 2.1.7
  * Refresh anki-anki_lang.py.patch
  * Support Qt > 5.9
  * Remove python3-devel dependency for noarch package
  2.1.1:
  * Fixed exporting of .apkg files with regular scheduler.
  * Extract embedded images when pasting HTML.
  * When the sort field is set to RTL, display in RTL order in
    the browser.
  2.1.2:
  * Add missing .apkg and .colpkg file associations.
  * Improve handling of images inlined in fields.
  2.1.3:
  * Hardware acceleration can now be toggled in the preferences
    screen.
  * Disable question fade-in during review when hardware
    acceleration is off.
  * Fix some add-ons leaving a blank space in the main window when
    Anki restarted.
  * Fix some unwanted text being included when pasting.
  * Fix shortcut keys like space from repeatedly triggering when
    held down.
  2.1.4:
  * Fix deck list getting stuck when creating filtered deck.
  * Prevent local cards being overwritten when accidentally
    downloading empty AnkiWeb collection.
  * Favour mark/flag colour over suspended colour in browse screen.
  * Fix new day calculation in experimental scheduler.
  * Linux theme tweaks.
  * Disable view page button for locally added add-ons.
  2.1.5:
  * Use selected answer button instead of default when enter/space
    pressed.
  * Change undo shortcut in browse screen to avoid conflict with
    editing functionality.
  * Ignore standard mpv config file location in favour of Anki data
    folder.
  * Fix importing of .apkg files when interface in Dutch.
  * Fix translations not working on Linux after make install.
  * Support newlines in type:cloze, and treat them as spaces.
  * Add browser.rowChanged hook for add-on authors.
  * Possible fix for some database is locked errors.
  * Fix errors on startup when deck given an invalid name.
  * Fix sorting not working when field contains only a media
    reference.
  * Fix access denied error not being caught properly.
  * Fix exporting of v2 colpkg when interface in non-English
    language.
  * Fix conditional replacement not ignoring HTML formatting.
  * Fix question fade time being forced when hardware acceleration
    on.
  * Add a small margin between buttons during review.
  * V2 scheduler now respects maximum interval even if it will lead
    to all buttons giving the same interval.
  * Tweak margins in overview and answer button areas.
  * Ignore UI events that are received after collection has been
    closed.
  * Don’t try to import .anki(2) files as text.
  * Added support for Lojban
  2.1.6:
  * Improvements to the Browse screen and flagging:
  - Search text is normalized, which fixes problems searching for
    unicode characters with multiple possible encodings.
  - The selection is now partially transparent, allowing you to
    see the underyling colours of the rows.
  - The screen doesn’t scroll when performing actions that don’t
    change the selection count.
  - Flags now toggle on and off, and the separate clear flag
    action has been removed.
  - The second flag is now orange instead of purple.
  - Find&replace now only shows fields relevant to the notes
    you’ve selected, and is case insensitive.
  - Fix card list not updating when editing HTML.
  * Importing apkgs is now more verbose about how notes have been
    handled.
  * Prevent errors caused by the user adding a field reference to
    itself on a field.
  * Better handle issues with the deck list, such as decks that are
    missing a parent deck.
  * Anki should now be able to function even if a system proxy is
    configured for localhost connections.
  * Fix font size being copied when pasting between Anki fields
    with bold text.
  * Pasting a link with shift held down now creates a clickable
    link.
  * Fixed an issue with the bulk remove tags option where tags with
    similar names could be removed as well.
  * Fixed an issue running latex commands on some Linux installs.
  * The Browse screen’s sidebar now defaults to on.
  * Fixed a race condition that could cause two copies of Anki to
    open.
  * When adding media to cards, Anki now will automatically rename
    the filenames if they’re too long.
  * The experimental scheduler now regularly checks if new learning
    cards have become due.
  * Handle invalid add-on config.
  * Enforce template ordering when card templates are reordered
    after card creation.
  * Don’t change deck when Esc pressed in deck chooser.
  * Fix a problem on initial startup when English not the default
    language.
  * Fix busy cursor showing in import results screen.
  * Fix content overlap when add-ons have added many editor buttons
  * Don’t change current note when reopening editor from review
    screen.
  * A fix for running on Python 3.7.
  * Restore the tooltip for the Fields and Cards buttons in editor.
  2.1.7:
  * Fix "QPushButton has been deleted" error messages after a
    problem occurs changing note types.
  * Fix errors during "Check Database" that are just a byproduct
    of a previous operation that failed.
  * Fix problems searching for some non-Latin text in decks/note
    type names.
  * Ensure cgi and uuid modules are available to add-ons.
  * Automatically restart mpv if it stops responding.
  * Don’t convert non-Latin characters in add-on configuration to
    difficult-to-read escape codes.
* Tue Aug  7 2018 toddrme2178@gmail.com
- Update to 2.1.0. See https://apps.ankiweb.net/docs/changes.html#changes-in-anki-2.1
  for the list of changes.
  * Anki 2.1 uses the same scheduling, syncing and file format as Anki 2.0.x, so you can upgrade and downgrade at will.
  * It’s built with recent support libraries (Python 3.6, Qt 5.9), bringing fixes for crashes, better handling of high resolution displays, non-Latin text, and the latest web standards.
  * It requires a modern system - Windows 7+, OSX 10.10+, or a Linux distro from around 2014+.
  * Add-ons will need to be updated to work with 2.1.
  * Built in MathJax support
  * A "restore backup" option in the profiles screen
  * SVG rendering support for LaTeX
  * Improved add-on configuration, management and updating
  * Night mode for reviewing
  * Improved pasting, with less unnecessary formatting included, and better handling of media links. You can hold the shift key when pasting to allow more formatting to be included.
- Rebase patches:
  * anki-anki_lang.py.patch
  * anki-aqt___init__.py.patch
- Remove unneeded patches
  * anki-Makefile.patch
- Update appdata url
- Anki uses python3 and Qt5 now.
* Mon Aug 21 2017 jan@hilberath.de
- Update to 2.0.47. See https://apps.ankiweb.net/docs/changes.html
  for the list of changes.
* Tue Mar 28 2017 jan.hilberath@suse.com
- Update to 2.0.45. See https://apps.ankiweb.net/docs/changes.html
  for the list of changes.
* Mon Jan  9 2017 psimons@suse.com
- Update to 2.0.39. See http://ankisrs.net/docs/changes.html for
  the list of changes.
* Wed Jul 13 2016 l.lunak@centrum.cz
- fixes to find translations in openSUSE-specific paths
* Sat May 14 2016 dap.darkness@gmail.com
- Update to 2.0.36, announce messages are here:
  http://ankisrs.net/docs/changes.html
* Sun Oct 11 2015 nemysis@openSUSE.org
- Update to 2.0.33, announce messages are here:
  http://ankisrs.net/docs/changes.html
* Sun Jun 28 2015 nemysis@gmx.ch
- Remove not working
  %%post %%mimedatabasepost and postun %%mimedatabasepostun
- Add update-mime-database %%{_datadir}/mime and
  update-mime-database %%{_datadir}/mime
* Sat Jun 27 2015 nemysis@gmx.ch
- Add BuildRequires for shared-mime-info
- Add %%post %%mimedatabasepost and postun %%mimedatabasepostun
- Change anki.appdata.xml
* Fri Jun 19 2015 nemysis@gmx.ch
- Update to 2.0.32, announce messages are here:
  http://ankisrs.net/docs/changes.html
- Use anki-Makefile.patch instead of many sed, imported from FreeBSD
- Simplify installation handling, use normal build
- Add anki.appdata.xml, imported from RedHat/Fedora
- Reorder BuildRequires
- Remove  Requires for xdg-utils
- Change Description and add how to change Language
- Add sed, Don't check for new updates
- Change how to compile python
- Use symlink for %%fdupes
- Use %%{_mandir}/man1/%%{name}.1%%{ext_man} instead of %%{_datadir}/man/man1/%%{name}.1*
* Fri Sep 27 2013 barendartchuk@suse.com
- updated to 2.0.12
- removed the pyqtconfig workaround patch as the fix has been merged in
  upstream issue #831
- added dependency on python-send2trash
- upstream changes since 2.0.12:
  * The complete list of changes is available at
    http://ankisrs.net/docs/changes.html#changes-in-2.0.12
  * Allow includegraphics in LaTeX
  * You can now view stats on filtered decks.
  * Work around linux crash on paste of invalid image.
- changes since 2.0.10:
  * Default to allowing HTML on import
- changes since 2.0.9:
  * The browser now has a preview button that makes it easier to quickly
    browse previews of cards.
  * If Anki detects that the media is out of sync, it will now automatically
    recover on the next sync. Furthermore, it no longer needs to send files
    that already exist on each side, so when this change is incorporated into
    the mobile clients you’ll be able to copy media over to them to avoid a
    long initial media sync.
  * When media is deleted via a sync or unused media, it’s now placed in the
    OS’s trash folder instead of deleted completely. Likewise for rotated
    backups and
    profile deletions.
  * When notes are deleted, their content is logged in a file called
    deleted.txt
    in your profile folder.
  * Ctrl+Shift+T (Command+Shift+T on a Mac) now jumps to the Tags entry
    field.
  * Allow HTML in Mnemosyne import
  * Workaround a Qt bug that was preventing clicks on the sidebar in the
    browser (thanks to Frostshutz)
  * Pauker importer (thanks to Frostshutz)
  * When using change deck, select the current deck by default.
  * When studying a filtered card, clicking Add will default to that deck.
* Thu Apr  4 2013 mvyskocil@opensuse.org
- update to 2.0.8
  * Fixed an issue with upgrading some Anki 1 decks.
  * Allow apostrophe in deck names.
  * Some changes which should speed up upgrading old Anki 1 decks.
  * When rescheduling is off in a filtered deck, show "(end)" on buttons that
    will end studying of that card.
  * Fix extra spaces being included when showing tags on card.
  * Make sure we switch back to the previous deck when creation of a filtered
    deck cancelled.
  * Fix a bug that was causing the automatically generated Reading field in the
    Japanese Support add-on to be blanked out again if you clicked directly on
    the Reading field.  and many more, see
  * http://ankisrs.net/docs/changes.html#latest
- drop libqt4-devel dependency hardcoding the qtmajor and qtminor during build
  * anki-remove-pyqtconfig.patch
- drop uneeded anki-indentation.patch
* Sat Nov 17 2012 mailaender@opensuse.org 
- update to 2.0.3
  * Fix some more issues with importing content that used a modified version of models already present in your collection. Decks (including 1.2 decks) are now imported in such a way that repeatedly importing them will no longer result in duplicate note types, notes or cards. The duplicate check only works against previous imports made in 2.0.3 however, so if you imported decks with divergent models in a previous Anki 2 version, the first time you import that content again, a duplicate will be created.
  * Fix a few errors that could occur when renaming decks.
  * Fix timeboxing counting one too many cards on the first session and not accounting for undone reviews.
  * Suspended cards now have their due date shown surrounded by brackets in the browser.
  * When a learning card is suspended, it is moved back to new if it was in initial learning, or moved back to a review card if it was in relearning.
  * Fix 1+ day steps not working for relearning cards.
  * Fixed some issues with settings not syncing due to the collection being accidentally marked as modified when it was loaded.
  * Add decimal point to reviews a day statistic.
  * When creating a filtered deck, default to searching through the current deck.
  * Display a progress window when closing the collection, as it may take a while.
  * Fix font size setting in Add Field button.
* Wed Oct 10 2012 mvyskocil@suse.com
- update to 2.0.0
  * Reviews are limited to 100/day by default.
  * When you answer "again", there are now two learning reviews of
  the card, so the red count will increase by two.
  * Cloze deletion has been much improved, but now requires you to
  select a special cloze type (the top left button in the Add window).
  * Selective study is still possible, but is done differently. You
  can either move cards into different decks (via Change Deck in the
  card browser), or create a filtered deck that searches for particular
  tags, card properties and so on.
  * Algorithm for selecting cards in multiple direction is changed
  * Anki only checks the first field to see if it’s unique now.
  * see http://ankisrs.net/docs/dev/changes.html
  for details
- libanki tests runs when build --with tests, disabled by default
- python-beautifulsoup is now required
- python-numpy and python-mathplotlib are no recommended as I did not
  find a file which uses them
- dropped anki-noupdate.patch
- add anki-indentation.patch
- install anki to /usr/share/anki, like upstream Makefile does
* Sun Oct  7 2012 lars@linux-schulserver.de
- update to 1.2.11
- remove anki-sawarning-unicode-column.patch
- specfile cleanup
* Wed Dec  7 2011 halsmit@t-online.de
- Fix 'SAWarning: Unicode column received non-unicode default value'
  Create a unicode string from a literal like it is done in the rest of
  that file.
* Sat Nov 19 2011 toddrme2178@gmail.com
- Removed unnecessary python-sqlite2 dependency that was preventing
  installation on openSUSE 12.1.  According to the readme this is
  unneccessary if python 2.5 is used, which all supported openSUSE
  versions have.
- Renamed python-sqlalchemy to python-SQLAlchemy to reflect changed
  package name
- Added version requirements for requires and buildrequires, taken
  from the readme
- Changed numpy from requires to recommends, since it adds optional
  features but is not needed for basic functionality
- Added recommends for matplotlib, since the feature numpy supports
  will not work unless matplotlib is also installed
- Added suggests for other optional packages that add functionality
  like audio playback, audio recording, and file conversion.
  These are suggets since many of them are not available in the
  default openSUSE release due to licensing issues
- Fixed permissions for a file (fix for RPMLINT warning)
* Fri Sep 30 2011 arun@nubati.net
- update to 1.2.9
* Wed Nov 17 2010 remy.marquis@opensuse.org
- Update to 1.0.1
- Disabled autoupdate feature
- Patched anki to remove python-qt4-devel depandancy
* Thu Jan  7 2010 bphilips@novell.com
- Add python-qt4-devel as dependency since anki requires the module
  pyqtconfig
* Mon Jul 20 2009 lrupp@suse.de
- update to 0.9.9.8.5:
  + Browser improvements
  + Importing improvements
  + Improved translations
  + Export original media
  + more robust LaTeX handling
  + fixed some bugs
- fix os-edu#71: added python-qt4, libqt4, libQtWebKit4 to Req.
* Fri May  8 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.9.9.7.9
* Thu Apr 30 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.9.9.7.7
* Tue Apr 21 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.9.9.7.5
* Sat Jul 26 2008 bitshuffler #suse@irc.freenode.org
- Initial RPM
